==> crm-commom-vo-1.1.7.1.release.jar: com/biz/crm/nebular/mdm/customer/MdmCustomerTerminalRespVo.java <==
package com.biz.crm.nebular.mdm.customer;

import com.biz.crm.nebular.mdm.CrmBaseVo;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 返回vo
 *
 * @author zxw
 * @date 2020-09-02 14:10:25
 */
@Data
@ApiModel(value = "客户信息：关联终端")
@SaturnEntity(name = "MdmCustomerTerminalRespVo", description = "客户信息：关联终端")
public class MdmCustomerTerminalRespVo extends CrmBaseVo {

    @ApiModelProperty("客户id")
    @SaturnColumn(description = "客户id")
    private String customerId;

    @ApiModelProperty("客户编码")
    @SaturnColumn(description = "客户编码")
    private String customerCode;

    @ApiModelProperty("终端编码")
    @SaturnColumn(description = "终端编码")
    private String terminalCode;

    @ApiModelProperty("终端名称")
    @SaturnColumn(description = "终端名称")
    private String terminalName;

    @ApiModelProperty("终端类型")
    @SaturnColumn(description = "终端类型")
    private String terminalType;

    @ApiModelProperty("终端类型名称")
    @SaturnColumn(description = "终端类型名称")
    private String terminalTypeName;

    @ApiModelProperty("终端地址")
    @SaturnColumn(description = "终端地址")
    private String terminalAddr;

    @ApiModelProperty("所属组织编码")
    @SaturnColumn(description = "所属组织编码")
    private String orgCode;

    @ApiModelProperty("所属组织名称")
    @SaturnColumn(description = "所属组织名称")
    private String orgName;

    @ApiModelProperty("客户组织编码")
    @SaturnColumn(description = "客户组织编码")
    private String customerOrgCode;

    @ApiModelProperty("客户组织名称")
    @SaturnColumn(description = "客户组织名称")
    private String customerOrgName;
}

==> crm-commom-vo-1.1.9.45.release.jar: com/biz/crm/nebular/mdm/customer/MdmCustomerTerminalRespVo.java <==
package com.biz.crm.nebular.mdm.customer;

import com.biz.crm.config.CrmDict;
import com.biz.crm.nebular.mdm.CrmBaseVo;
import com.biz.crm.nebular.mdm.constant.DictConstant;
import com.bizunited.platform.saturn.engine.annotation.SaturnColumn;
import com.bizunited.platform.saturn.engine.annotation.SaturnEntity;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

/**
 * 返回vo
 *
 * @author zxw
 * @date 2020-09-02 14:10:25
 */
@Data
@ApiModel(value = "客户信息：关联终端")
@SaturnEntity(name = "MdmCustomerTerminalRespVo", description = "客户信息：关联终端")
public class MdmCustomerTerminalRespVo extends CrmBaseVo {

    @ApiModelProperty("客户id")
    @SaturnColumn(description = "客户id")
    private String customerId;

    @ApiModelProperty("客户编码")
    @SaturnColumn(description = "客户编码")
    private String customerCode;

    @ApiModelProperty("终端编码")
    @SaturnColumn(description = "终端编码")
    private String terminalCode;

    @ApiModelProperty("终端名称")
    @SaturnColumn(description = "终端名称")
    private String terminalName;

    @ApiModelProperty("终端类型")
    @SaturnColumn(description = "终端类型")
    private String terminalType;

    @ApiModelProperty("终端类型名称")
    @SaturnColumn(description = "终端类型名称")
    @CrmDict(typeCode = DictConstant.TERMINAL_TYPE,dictCodeField = "terminalType")
    private String terminalTypeName;

    @ApiModelProperty("终端地址")
    @SaturnColumn(description = "终端地址")
    private String terminalAddr;

    @ApiModelProperty("所属组织编码")
    @SaturnColumn(description = "所属组织编码")
    private String orgCode;

    @ApiModelProperty("所属组织名称")
    @SaturnColumn(description = "所属组织名称")
    private String orgName;

    @ApiModelProperty("客户组织编码")
    @SaturnColumn(description = "客户组织编码")
    private String customerOrgCode;

    @ApiModelProperty("客户组织名称")
    @SaturnColumn(description = "客户组织名称")
    private String customerOrgName;
}
